rfc3986_validator: Pure python rfc3986 validator
================================================

Description
-----------

Pure python rfc3986 validator

License
-------

MIT license

Upstream Contact
----------------

https://pypi.org/project/rfc3986-validator/

